# Rust component

The majority of the Glean SDK is implemented as a Rust component, to be usable across all platforms.

This includes:

* Implementations of all metric types
* A storage layer
* A ping serializer
